.. _APIReferenceCollections:

Collections Class
==============================

.. autoclass:: imagedata.Study
    :members:

.. autoclass:: imagedata.Patient
    :members:

.. autoclass:: imagedata.Cohort
    :members:
